@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 my %introduces = ( 5.024 => [qw[
                                  unicode8.0 \b{lb} sprintf-reorder
@@ -19,7 +19,7 @@ my %introduces = ( 5.024 => [qw[
                                  unicode6.3 \p{Unicode} utf8-locale
                               ]],
                    5.018 => [qw[
-                                 computed-labels
+                                 computed-labels while-each
                               ]],
                    5.014 => [qw[
                                  ?^ /r /d /l /u /a auto-deref
@@ -32,8 +32,9 @@ my %introduces = ( 5.024 => [qw[
                               ]],
                    5.010 => [qw[
                                  // ?PARNO ?<> ?| quant+ regex-verbs
-                                 \K \R \gN readline() stack-file-test
-                                 recursive-sort /p lexical-$_
+                                 \K \R \v \h \gN readline()
+                                 stack-file-test recursive-sort /p
+                                 lexical-$_
                               ]],
                  );
 
@@ -103,7 +104,7 @@ Syntax::Construct - Identify which non-feature constructs are used in the code.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =head1 SYNOPSIS
 
@@ -235,10 +236,11 @@ expressions> or L<perlre/Special Backtracking Control Verbs>.
 "\K escape" under L<perl5100delta/Regular expressions> or
 L<perlre/Look-Around Assertions>.
 
-=head3 \R
+=head3 \R \v \h
 
-"Vertical and horizontal whitespace, and linebreak" under
-L<perl5100delta/Regular expressions> or L<perlrebackslash/Misc>.
+Covers C<\V> and C<\H>, too. See "Vertical and horizontal whitespace,
+and linebreak" under L<perl5100delta/Regular expressions> or
+L<perlrebackslash/Misc>.
 
 =head3 \gN
 
@@ -358,6 +360,10 @@ No non-feature constructs were introduced in this version of Perl.
 
 L<perl5180delta/Computed Labels>
 
+=head3 while-each
+
+See in L<perl5180delta/Selected Bug Fixes> or C<each> in L<perlfunc>.
+
 =head2 5.020
 
 =head3 attr-prototype
